@@ -8,8 +8,8 @@
 //!
 
 use crate::{Error, Result};
-use std::convert::TryInto;
 use tor_cell::chancell::RawCellBody;
+use tor_error::internal;
 
 use generic_array::GenericArray;
 
@@ -224,9 +224,8 @@ pub(crate) type Tor1RelayCrypto =
 /// Incomplete untested implementation of Tor's current cell crypto.
 pub(crate) mod tor1 {
     use super::*;
-    use cipher::{NewCipher, StreamCipher};
+    use cipher::{KeyIvInit, StreamCipher};
     use digest::Digest;
-    use std::convert::TryInto;
     use typenum::Unsigned;
 
     /// A CryptState is part of a RelayCrypt or a ClientLayer.
@@ -252,13 +251,16 @@ pub(crate) mod tor1 {
         back: CryptState<SC, D>,
     }
 
-    impl<SC: StreamCipher + NewCipher, D: Digest + Clone> CryptInit for CryptStatePair<SC, D> {
+    impl<SC: StreamCipher + KeyIvInit, D: Digest + Clone> CryptInit for CryptStatePair<SC, D> {
         fn seed_len() -> usize {
             SC::KeySize::to_usize() * 2 + D::OutputSize::to_usize() * 2
         }
         fn initialize(seed: &[u8]) -> Result<Self> {
             if seed.len() != Self::seed_len() {
-                return Err(Error::InternalError("length is invalid".to_string()));
+                return Err(Error::from(internal!(
+                    "seed length {} was invalid",
+                    seed.len()
+                )));
             }
             let keylen = SC::KeySize::to_usize();
             let dlen = D::OutputSize::to_usize();
@@ -439,8 +441,8 @@ mod test {
             // outbound cell
             let mut cell = [0_u8; 509];
             let mut cell_orig = [0_u8; 509];
-            rng.fill_bytes(&mut cell_orig[..]);
-            (&mut cell).copy_from_slice(&cell_orig[..]);
+            rng.fill_bytes(&mut cell_orig);
+            cell.copy_from_slice(&cell_orig);
             let mut cell = cell.into();
             let _tag = cc_out.encrypt(&mut cell, 2.into()).unwrap();
             assert_ne!(&cell.as_ref()[9..], &cell_orig.as_ref()[9..]);
@@ -453,8 +455,8 @@ mod test {
             // inbound cell
             let mut cell = [0_u8; 509];
             let mut cell_orig = [0_u8; 509];
-            rng.fill_bytes(&mut cell_orig[..]);
-            (&mut cell).copy_from_slice(&cell_orig[..]);
+            rng.fill_bytes(&mut cell_orig);
+            cell.copy_from_slice(&cell_orig);
             let mut cell = cell.into();
 
             r3.originate(&mut cell);
