@@ -2,5 +2,5 @@
 
 pub(crate) mod ct;
 pub(crate) mod err;
-#[cfg(feature = "traffic-timestamp")]
+pub(crate) mod skew;
 pub(crate) mod ts;
